==> v8.3.zip: ru_twords_ru_tw/bible/kt/sanctuary.md <==
# святилище

## Определение:

Слово “святилище” означает “святое место” и относится к такому месту, которое Бог сделал священным и неосквернённым. Святилищем также может называться безопасное место, где можно найти защиту.

* В Ветхом завете слово “святилище” часто используется в отношении скинии или храма, где находилось Святое и Святое Святых.
* Бог относится к святилищу как к месту, где Он обитает среди израильского народа.
* Он также и Самого Себя называет “Святилищем” — безопасным местом для Своего народа, где люди могут найти защиту.

## Варианты перевода:

* Основное значение этого слова — “отделённое место”.
* В зависимости от контекста слово “святилище” можно перевести как “святое место”, “священное здание”, “место Божьего обитания”, “святое место для защиты” или “святое безопасное место”.
* Выражение “священный сикль” может быть переведено как “сикль, отданный в скинию” или “сикль — налог на содержание храма”.
* Убедитесь, что перевод слова “святилище” в Библии не имеет значения “комната для поклонения в современной церкви”.

(См. также: [святой](../kt/holy.md), [Дух Святой](../kt/holyspirit.md), [отделять](../kt/setapart.md), [скиния](../kt/tabernacle.md), [налог](../other/tax.md), [храм](../kt/temple.md), )

## Ссылки на библейский текст:

* [Amos 7:12-13](rc://*/tn/help/amo/07/12)
* [Исх. 25:3-7](rc://*/tn/help/exo/25/03)
* [Иез. 25:3-5](rc://*/tn/help/ezk/25/03)
* [Евр. 8:1-2](rc://*/tn/help/heb/08/01)
* [Лк. 11:49-51](rc://*/tn/help/luk/11/49)
* [Чис. 18:1-2](rc://*/tn/help/num/18/01)
* [Пс. 78:67-69](rc://*/tn/help/psa/078/067)

## Данные о слове:

* Номера Стронга: H4720, H6944, G39

==> v9.2.zip: ru_twords_ru_tw/bible/kt/sanctuary.md <==
# святилище
## Определение:

Слово “святилище” означает “святое место” и относится к такому месту, которое Бог сделал священным и неосквернённым. Святилищем также может называться безопасное место, где можно найти защиту.
* В Ветхом завете слово “святилище” часто используется в отношении скинии или храма, где находилось Святое и Святое Святых.
* Бог относится к святилищу как к месту, где Он обитает среди израильского народа.
* Он также и Самого Себя называет “Святилищем” — безопасным местом для Своего народа, где люди могут найти защиту.

## Варианты перевода:

* Основное значение этого слова — “отделённое место”.
* В зависимости от контекста слово “святилище” можно перевести как “святое место”, “священное здание”, “место Божьего обитания”, “святое место для защиты” или “святое безопасное место”.
* Выражение “священный сикль” может быть переведено как “сикль, отданный в скинию” или “сикль — налог на содержание храма”.
* Убедитесь, что перевод слова “святилище” в Библии не имеет значения “комната для поклонения в современной церкви”.

(См. также: [святой](../kt/holy.md), [Дух Святой](../kt/holyspirit.md), [отделять](../kt/setapart.md), [скиния](../kt/tabernacle.md), [налог](../other/tax.md), [храм](../kt/temple.md), )

## Ссылки на библейский текст:

* [Amos 7:12-13](rc://ru/tn/help/amo/07/12)
* [Исх. 25:3-7](rc://ru/tn/help/exo/25/03)
* [Иез. 25:3-5](rc://ru/tn/help/ezk/25/03)
* [Евр. 8:1-2](rc://ru/tn/help/heb/08/01)
* [Лк. 11:49-51](rc://ru/tn/help/luk/11/49)
* [Чис. 18:1-2](rc://ru/tn/help/num/18/01)
* [Пс. 78:67-69](rc://ru/tn/help/psa/078/067)

## Данные о слове:

* Номера Стронга: H4720, H6944, G39
